# Changelog

## [0.1.6] - 2025-12-10
- Updated airbyte-agent-mcp package
- Source commit: 92482e66
- SDK version: 0.1.0

## [0.1.5] - 2025-12-10
- Updated airbyte-agent-mcp package
- Source commit: b3c6a176
- SDK version: 0.1.0

## [0.1.4] - 2025-12-10
- Updated airbyte-agent-mcp package
- Source commit: b3c6a176
- SDK version: 0.1.0

## [0.1.3] - 2025-12-10
- Updated airbyte-agent-mcp package
- Source commit: b3c6a176
- SDK version: 0.1.0

## [0.1.2] - 2025-12-10
- Updated airbyte-agent-mcp package
- Source commit: b3c6a176
- SDK version: 0.1.0

## [0.1.1] - 2025-12-10
- Updated airbyte-agent-mcp package
- Source commit: b3c6a176
- SDK version: 0.1.0

## [0.1.0] - 2025-12-09
- Updated airbyte-agent-mcp package
- Source commit: b3c6a176
- SDK version: 0.1.0
